# Fast Recovery (Version: OpenSM 5.15.0)

Fast recovery is used to detect unhealthy ports reported by switch FW.
SM configures fast recovery parameters for each switch port.

## OpenSM configuration

#### Enable Fast Recovery
In order to enable fast recovery, set the parameter *fast_recovery_enabled*
in OpenSM configuration file to *2*
For example:
```
fast_recovery_enabled 2
```
To disable fast recovery, set parameter value to *1*
To ignore, meaning avoid configuring fast recovery (if was already configured,
SM will not disable), set parameter value to *0*

#### Defining Fast Recovery configuration file

To define a fast recovery configuration file, set the parameter
*fast_recovery_conf_file* in OpenSM configuration file to point to
fast recovery configuration file.
For example:
```
fast_recovery_conf_file /etc/opensm/conf/fast_recovery.cfg
```

## Fast recovery Configuration
Fast recovery parameters are per port, and defined by configuration file.
Each port group gets set of parameters for each section, which represents Fast Recovery feature - CreditWatchdog, raw BER, symbol BER, effective BER.
+ **port_group_name** - defines which switch ports this configuration applies to.
  Predefined ports groups (such as ALL_SWITCHES, ALL_SW_TO_CA, ALL_SW_TO_SW, etc) or groups from port group policy file (see *doc/port-groups.txt*) can be used as port group name.
#### Parameters
+ **error_thr_action** - which action FW applies when reaching error threshold. 
  Supported values:
  + no_reset - does nothing.
  + physical_reset - toggle the physical link (drop to polling).
  + logical_reset - change logical state to Init.
+ **enable_threshold** - which thresholds to enable for this setcion.
  Supported values: none / error / warning_normal / all.
##### Credit Watchdog
+ **error_threshold** - refers to the number of credit watchdog events that occurred in the specific time window. When the switch reaches this threshold it shall act according to error_thr_action.
  Supported values: positive number up to 31.
+ **warning_threshold** - number of credit watchdog events that occurred in the specific time window. Shall be smaller than error_threshold when set.
  Supported values: positive number up to 31.
+ **normal_threshold** - number of credit watchdog events that occurred in the specific time window. Shall be smaller than warning_threshold.
  Supported values: positive number up to 31.
+ **time_window** - The time frame which the events are grouped. Units of Sampline_rate
  Supported values: positive number, up to 255.
+ **sampling_rate** - Time frame to measure warning threshold and error threshold. Units of 10mSec, range 0..1Sec.
  Supported values: positive number, up to 100.
##### BER (same for all 3 BER types)
+ **apply_thresholds** - When set to fw_default, the device shall reply with its default thresholds, hence no need to mention threshold values. If parameter is not mentioned, shall use SM configuration parameters.
  Supported values: fw_default / sm_config
+ **error_threshold** - Supported values: please see below.
+ **warning_threshold** - Supported values: please see below.
+ **normal_threshold** - Supported values: please see below.

> **BER threshold supported values**
> Supported ranges according to BER type:
> - raw BER: [10^-9^, 10^-4^]
> - symbol BER: [10^-14^, 10^-8^]
> - effective BER: [10^-17^, 10^-10^]
> 
> Please use the following syntax: 0.00002 / 2e-5 (e represents demical base)

#### Example for Fast Recovery configuration file:
```
port_conf_start
	port_group_name: ALL_SWITCHES

	credit_watchdog_start
		error_thr_action: no_reset
		enable_threshold: all
		error_threshold: 31
		warning_threshold: 1
		normal_threshold: 0
		time_window: 1
		sampling_rate: 1
	credit_watchdog_end

	raw_ber_start
		error_thr_action: no_reset
		enable_threshold: all
		error_threshold: 0.00002
		warning_threshold: 1e-6
		normal_threshold: 3e-8
	raw_ber_end

	effective_ber_start
		apply_thresholds: fw_default
		error_thr_action: no_reset
		enable_threshold: all
	effective_ber_end

	symbol_ber_start
		apply_thresholds: fw_default
		error_thr_action: no_reset
		enable_threshold: all
	symbol_ber_end
port_conf_end
```
