# MLNXSM 5.11.0

Copyright (c) 2022 NVIDIA CORPORATION & AFFILIATES. All rights reserved.  
April 2022


## Packages:

| Package | Version     |
| ------- | ----------- |
| UFM     | 6.9.0       |
| MOFED   | 5.6         |


## Main features

- Self healing network with PFRN  
  Use PFRN for fast link fault recovery. If link fails or disconnects, switches send messages to 
  peer switches to update routing tables.  
  Feature supported only on *ar_updn* and *ar_ftree* routing engine.  
  It is assumed that all fabric switches support PFRN (Quantum and Quantum2 only).  
  Feature control parameters:  
  *pfrn_sl* - SL for PFRN messages (default SL 0).  
  *pfrn_mask_clear_timeout* - Timeout since the last PFRN message received by the switch for an AR group, after which unused port masks will be cleared.
  The value is in multiplies of 30 seconds. (default 180)  
  *pfrn_mask_force_clear_timeout* - Timeout since last mask clear operation, after which unused port masks are cleared by the switch.
  The value is in multiplies of 240 seconds. (default 720)  
  In order to disable PFRN, set *shield_mode* value to 2.  

- Multiport high availability  
  Allows SM to failover to another port in the case of SM link failure.  
  Requires configuring more than one port GUID in the *guid* parameter.  
  Feature control parameter:  
  *enable_sm_port_failover* - Enable or disable failover (default FALSE).  

- Support Hash Based Forwarding (HBF)  
  Allows selection of the switch outgoing port for statically routed packets, based on packet parameters (ECMP like).  
  With *dfp2* routing engine, non-minhop routes will be used for static routing as well as for adaptive routing.  
  Feature control parameters:  
  *hbf_sl_mask* - SLs supporting HBF (default 0).  
  *hbf_hash_type* - Hash function for HBF  
  - 0 - CRC (default).  
  - 1 - XOR.  

  *hbf_seed_type* - Hash seed type:  
  - 0 - Seed (default).  
  - 1 - Random.  

  *hbf_seed* - Hash seed, 32 bit number:  
  - 0xffffffff - Use switch GUID for seed (default).  
  - 0x0-0xfffffffe - Specific seed value.  

  *hbf_hash_fields* - Fields of packet for hash calculation (default 0x40F00C0F).  
  *hbf_weights* - Weights ratio between ports of different AR sub-groups:  
  -  auto - SM/routing engine decision (default).  
  - \<sg0\>,\<sg1\>,\<sg2\> - User defined weights for subgroup 0 to subgroup 2.   


## Changes

- Improved SA response time for multicast join requests during routing calculation.

- Support persistent mapping between AR group ID to the destination switch GUID.

- Implemented workaround in dfp2 for FW limitation (switch SMA response MADs are routed using PLFT0).

- Added SM ports table to SMDB.

- Added ConnectX-8 device IDs to SM lists.

- Changed verbosity of log message when toggling ports to INFO.

- Report to log when failing to update port state from ARM to ACTIVE.

- Added details for virtualization traps to log file.

- Create statistics dump file per SM port by default.

- Enable asymmetric flow algorithm for trees (ar_updn and ar_ftree) by default.


## Parameter changes

| Parameter name                | Status | Type    | Description                                                                   |
| ----------------------------- | ------ | ------- | ------------------------------------------------------------------------------|
| pfrn_sl                       | New    | Number  | SL for PFRN messages. Default 0                                               |
| pfrn_mask_clear_timeout       | New    | Number  | Time since last PFRN for an AR group to clear unused port masks. Default 180  |
| pfrn_mask_force_clear_timeout | New    | Number  | Time since last mask clear, after which unused port mask is cleared by the switch. Default 720 |
| n2n_key_enable                | New    | Number  | Enable Node-to-Node Key (management class 0xC) configuration. Default 0 (Ignore) |
| n2n_key_protect_bit           | New    | Number  | Protection level for class 0xC. Default 1                                     |
| n2n_key_lease_period          | New    | Number  | Lease period for class 0xC key. Default 60                                    |
| n2n_max_outstanding_mads      | New    | Number  | Maximum number of N2N MADs in the network at once. Default 500                |
| enable_sm_port_failover       | New    | Boolean | Enable SM fail over to another port in case of link failure. Default is False |
| hbf_sl_mask                   | New    | Boolean | SL mask for HBF. Default 0x0000 (Disabled)                                    |
| hbf_hash_type                 | New    | Number  | HBF hash type. Default 0 (CRC)                                                |
| hbf_seed_type                 | New    | Number  | HBF seed type. Default 0 (User defined seed)                                  |
| hbf_seed                      | New    | Number  | Seed for HBF. Default 0xFFFFFFFF (Use switch GUID)                            |
| hbf_hash_fields               | New    | Number  | Fields of packet for hash calculation. Default 0x40F00C0F                     |
| hbf_weights                   | New    | String  | Weights ratio between ports of different groups. Default 'auto' (Routing algorithm decision) |
| cache_ar_group_id             | New    | Boolean | Load GUID to AR group ID cache file on startup. Default TRUE                  |
| ar_tree_asymmetric_flow       | Update | Number  | Changed default to 1.                                                         |
| sm_stats_dump_per_sm_port     | Update | Boolean | Changed default to TRUE,                                                      |


## Bug fixes

- Fixed unconditional jump on uninitialized value when in dfp2 when ar_sl_mask is set to 0.

- Fixed case of duplicated LIDs when persistent SM LID feature is enabled.

- Fixed invalidating ucast cache when discovering faulty switch.

- Fixed crash when detecting two ports of same node with different port GUID but same port number.

- Fixed traps 1310 and 1311 (duplicated GUIDs) type to 'security'.

- Fixed reporting trap 1312 to UFM.
