# MLNXSM 5.9.1

Copyright (c) 2021 NVIDIA CORPORATION & AFFILIATES. All rights reserved.
July 2021


## Packages:

| Package | Version |
| ------- | ------- |
| UFM     | 6.7.0   |


## Main features

- NDR Support in SM

- Configuration file validation  
  Add command line option *--validate_conf_files*, when used,
  SM only validate configuration files and exit afterwards.  
  Only validating partition file is currently supported.  

- Persistent MC trees  
  Read MFT tables on SM startup/fail-over in order to ensure new MASTER SM does not
  break multicast routing.  
  Feature control parameters:  
  - *get_mft_tables* - Enable/disable the feature. (default *TRUE*)  

- Support SHIELD for *dfp2* routing engine for DragonFly+ topologies.

- SM allowed GUIDs list  
  Specifying list of GUIDs allowed to run SM in the fabric.  
  When the list is provided, master SM will avoid handover to ports that are not specified in the list.
  Feature control parameters:  
  - *allowed_sm_guids* - List of GUIDs allowed to run SM.  
    When set to *"(null)"* - Feature disabled.  

- Limiting number of VLs for long distance links  
  Support setting max operational VL per port by a new file specified by
  *device_configutarion_file* parameter on opensm configuration file.  
  Feature control parameters:  
  - *device_configutarion_file* - Provide per port configuration.  

  For more information, see *doc/device_configuration.md*.  

- Allow disabling SHARP per device  
  Support enabling/disabling SHARP Aggregation node per device using port groups.  
  Feature control parameters:  
  - *device_configutarion_file* - Provide per port configuration.  

  For more information, see *doc/device_configuration.md*.  
  
- Send ClientReregister after subnet configuration  
  Send ClientReregister after subnet configuration to prevent from  
  hosts to send SA requests to SM before SM is ready to respond to them.  
  Feature control parameters:  
  - *client_rereg_mode* - Control modes of sending ClientRergister.  
    Supported values:  
    0 - Do not send client reregistration.  
    1 - Send client reregistration during LID assignment (previous default
        behavior).  
    2 - Send client reregistration after routing and QoS configuration from
        link manager. (default)  
    The new parameter deprecates *no_clients_rereg* parameter.  
  
- Add kDOR Generalized Hypercube engine


## Changes

- Print summary of AR and DF+ supported switches to log

- Improve performance of NR lookup by LID

- Change verbosity of port group creation messages to be in INFO level

- Add new statistics counters to opensm-statistics.dump

- Consider affinity when calculating number of cores


## Parameter changes

| Parameter name                        | Status | Type    | Description                                                  | 
| ------------------------------------- | ------ | ------- | ------------------------------------------------------------ |
| allowed_sm_guids                      | New    | String  | Define list of allowed SM port GUIDs                         |
| device_configuration_file             | New    | String  | Path to device configuration file                            |
| client_rereg_mode                     | New    | Number  | Control sending ClientReregister to devices                  |
| max_rate_enum                         | New    | Number  | Define maximal supported rate in SA recoreds                 |
| gmp_traps_threads_num                 | New    | Number  | Number of threads for processing GMP traps                   |
| get_mft_tables                        | New    | Boolean | Enable/Disable reading MFT tables on first master sweep      |
| routing_engine                        | Update | String  | Support *kdor-ghc* for Generalized Hypercube routing engine  |
| mepi_cache_enabled                    | Update | Boolean | Changed default from *FALSE* to *TRUE*                       |
| no_clients_rereg                      | Update | Boolean | Deprecated by *client_rereg_mode*                            |
| use_original_extended_sa_rates_only   | Update | Boolean | Deprecated by *max_rate_enum*                                |
| dfp_down_up_turns_mode                | Update | Number  | Changed default from *0* to *2* (disable down/up turns)      |
| routing_threads_num                   | Update | Number  | Changed default value from *1* to *0*                            |
| force_link_speed_ext                  | Update | Number  | Support NDR speeds                                           |


## Bug fixes

- Fix crash when isolating switch using *held_back_sw_guid* file 
  while running SM with updn/ar_updn and using GUIDs order file with
  port group that includes HCAs that are connected to a heldback switch

- Fix breaking routing for virtual port LIDs upon failover/restart

- Fix ar_ftree may create non-credit loop free routing between IO nodes

- Fix continuation of the discovery stage during subnet configuration stage

- Fix missing getting MEPI after switch reset

- Fix multicast group leak when handling leave of SendOnlyFullMembers of multicast groups

- Fix leak when spoofing notice 144 for virtual ports


