# OpenSM 5.7.1

July 2020

Packages:

| Package | Version |
| ------- | ------- |
| UFM     | 6.5.0   |


## Main features

- Support multiple ports.  
  Allow OpenSM to use multiple ports for sending subnet configuration MADs.  
  Feature control parameters:  
  - *guid* - Comma separated list of OpenSM port GUIDs.  
    First port GUID specifies primary port which used for Subnet Management (discovery, traps) and Subnet Administration.  
    Additional port GUIDs are used for sending subnet configuration (SMP Set MADs).  
    Configuration file example:  
      `guid 0x10001,0x10002`  

- Extend router selection algorithm.  
  Support specifying hash function, seed and additional hash function arguments for router selection during path records calculation.  
  Feature control parameters:  
  - *rtr_selection_function* - Hash function to be used by router selection algorithm.  
    Supported values - *crc32* (default).  
  - *rtr_selection_seed* - Seed for router selection algorithm. (default *0*)  
  - *rtr_selection_algo_parameters* - Comma separated list of parameters for router selection algorithm.  
    Supported values: *sgid*, *dgid*. (default *sgid, dgid*)  

- Support LMC for routers and number of LIDs allowed per router for inter-subnet path records.  
  Feature control parameters:  
  - *lids_per_rtr* - Defines number of Router LIDs to be used for inter-subnet path records.  
    When set to *0*, OpenSM will use number of LIDs per router according to global LMC. (default *0*)  
    When set to non-zero, OpenSM will set LMC for router ports according to the value of this  
    parameter (minimal N such that 2^N >= *lids_per_rtr*).  
    If global LMC is not zero, lids_per_rtr is ignored.  
    When lids_per_rtr is set to non-zero value, *updn*/*ar_updn*/*chain* with *updn* routing engines should be used.  

- Support Mellanox Congestion Control.  
  Feature control parameters:  
  - *mlnx_congestion_control* - Enabled/Disable Mellanox Congestion Control.  
    Supported values:  
    0 - Do not configure congestion control (default).  
    1 - Disable congestion control on the subnet.  
    2 - Configure congestion control according to policy file.  
  - *congestion_control_policy_file* - Path to congestion control policy file.  
    For additional information, please review congestion_control.md file provided with OpenSM.  

- Support LIDs range in Routing Chains.  
  Replaces path-bit qualifier in routing chain configuration by min-path-bit
  and max-path-bit qualifiers. (path-bit is still supported for backward compatibility).  
  Example of usage:  
      `min-path-bit: 1`  
      `max-path-bit: 3`  

- Support controlling maximum number of MADs on wire per destination.  
  Feature control parameters:  
  - *max_wire_smps_per_device* - Number of MADs on the wire per device. (default *2*)  

- Support configuring service keys to service name.  
  Allow configuring service keys to service names.  
  Feature control parameters:  
  - *service_name2key_map_file* - Path to service name to service key map file.  
    File contains mapping from service name to service key which is specified in IPv6 format.  
    For example, map service name <SERVICE NAME> service key 0::1 by adding the following line to the file:  
      `<SERVICE NAME> 0::1`  


## Changes

- Avoid sending PortInfo MADs to switch ports that did not change
  their state from the previous sweep.

- Enable Adaptive Routing for all SLs on switches.

- Set limit to SMInfo dispatcher queue.

- Improve performance of missing routes calculation for trees.

- Improve performance of ar_updn and ar_ftree routing engines.

- Improve performance of inter-subnet path record calculation.

- Log number of link resets by OpenSM at the end of heavy sweep.

- Disable creating subnet LST file as default  
  Feature control parameters:  
  - *enable_lst_file* - Controls dumping subnet LST file of the topology  
    If set to *TRUE*, LST file is created after heavy sweep. (default *FALSE*)  

- Remove LMC support from verbosity bypass.

- Allow empty port groups file in routing chains.

- Align index table columns in SMDB file.

- UPDN LID tracking - Add option to give precedence to exit ports leading to switch
  with lower total number of routes over exit ports leading to switch with less
  routes to the switch of the destination LID.  
  Feature control parameters:  
  - *updn_lid_tracking_prefer_total_routes*.  
    If set to *TRUE*, enable the feature. (default *FALSE*)  


- UPDN LID tracking - improve routing algorithm to improve routing utilization and
  routes balancing.

- UPDN LID tracking - Update routing engine to support LMC.


## Default configuration changes

- Change default value of *max_topologies_per_sw* from 1 to 4.

- Change default value of *scatter_ports* from 0 (disabled) to 8.

- Change default value of *log_flash* from *FALSE* to *TRUE*.

- Disable dumping subnet LST file by default.


## Parameter changes

| Parameter name                        | Status | Type    | Description                                                  |
| ------------------------------------- | ------ | ------- | ------------------------------------------------------------ |
| enable_lst_file                       | New    | Boolean | Control dumping subnet LST file of the topology              |
| lids_per_rtr                          | New    | Number  | Control number of LIDs per router of inter-subnet path record |
| max_wire_smps_per_device              | New    | Number  | Control maximum number of MADs on wire per device            |
| service_name2key_map_file             | New    | Path    | Path to service name to service key map file                 |
| rtr_selection_function                | New    | String  | Hash function to be used by router selection algorithm       |
| rtr_selection_seed                    | New    | Number  | Seed for router selection algorithm                          |
| rtr_selection_algo_parameters         | New    | String  | Comma separated list of parameters for router selection algorithm |
| updn_lid_tracking_prefer_total_routes | New    | Boolean | Control UPDN LID tracking exit port selection criteria       |
| mlnx_congestion_control               | New    | Number  | Control Mellanox Congestion Control enablement               |
| congestion_control_policy_file        | New    | Path    | Path to Congestion Control policy file                       |
| guid                                  | Update | List    | Changed type from GUID to list of comma separated GUIDs      |
| scatter_ports                         | Update | Number  | Changed default value from 0 (disabled) to 8                 |
| log_flash                             | Update | Boolean | Changed default value from FALSE to TRUE                     |
| max_topologies_per_sw                 | Update | Number  | Changed default value from 1 to 4                            |


## Bug fixes

- Fix memory overflow when removing virtual ports from subnet when using Adaptive Routing.

- Fix overriding PID file in init.d/opensmd which could cause SystemD to hang when crashd option is enabled.

- Fix handling ';' and ':' in nodes names in port groups policy file parser.

- Fix missing routes to routers after recovery in DF+ routing engine.

- Fix port_search_order usage when LMC is enabled.

- Fix SA LinkRecords and MultipathRecords LMC support.

- Fix partition checking for LinkRecord and PortInfoRecord queries.

- Fix calculating dedicated groups for switches with ANs when FRN enabled.

- Fix router support in port groups.

- Fix not dumping SADB when updating service records.
